#! /bin/sh
#
# tomcat-xvfb	Startup script for a virtual X framebuffer.
#
#	Written by Miquel van Smoorenburg <miquels@cistron.nl>.
#	Modified for Debian GNU/Linux by Ian Murdock <imurdock@gnu.ai.mit.edu>.
#       Tomcat-xvfb modifications by Stephen Peters <portnoy@portnoy.org>.

PATH=/sbin:/bin:/usr/sbin:/usr/bin
DAEMON=/usr/X11R6/bin/Xvfb
NAME=tomcat-xvfb
DESC="virtual X framebuffer for tomcat"

# You can override these settings by creating /etc/default/tomcat-xvfb
XVFB_CONFIG="800x600x8"
XVFB_OPTIONS=""
XVFB_DISPLAY=":1"

# The XVFB_DISPLAY should match the DISPLAY put in
# /etc/default/tomcat.  To be sure, we'll load it ourselves.

if [ -f /etc/default/tomcat ]; then
  . /etc/default/tomcat
elif [ -f /etc/default/tomcat4 ]; then
  . /etc/default/tomcat4
fi

test -n "$DISPLAY" && XVFB_DISPLAY="$DISPLAY"

# Overwrite the XVFB_* options, if the user creates this file.
if [ -f /etc/default/tomcat-xvfb ]; then
  . /etc/default/tomcat-xvfb
fi

test -f $DAEMON || exit 0
test "$XVFB_ENABLE" = "no" && exit 0

XVFB_OPTIONS="$XVFB_DISPLAY -screen 0 $XVFB_CONFIG $XVFB_OPTIONS"

PIDFILE="/var/run/$NAME.pid"

set -e

case "$1" in
  start)
	echo -n "Starting $DESC: "
	start-stop-daemon --start --quiet --pidfile "$PIDFILE" \
		--make-pidfile --background --exec $DAEMON -- $XVFB_OPTIONS 
	echo "$NAME."
	;;

  stop)
	echo -n "Stopping $DESC: "
	start-stop-daemon --oknodo --stop --quiet --pidfile "$PIDFILE" \
		--exec $DAEMON
	rm -f "$PIDFILE"
	echo "$NAME."
	;;

  restart|force-reload)
        $0 stop
	sleep 1
	$0 start
	;;
  *)
	N=/etc/init.d/$NAME
	echo "Usage: $N {start|stop|restart|force-reload}" >&2
	exit 1
	;;
esac

exit 0
